package com.inspect.metadata.montdata.mapper;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevAlmAbn;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface BasedataMontPatDevAlmAbnMapper {
   BasedataMontPatDevAlmAbn selectBasedataMontPatDevAlmAbnByMontPatDevAlmAbnId(Long id);

   List<BasedataMontPatDevAlmAbn> selectBasedataMontPatDevAlmAbnList(BasedataMontPatDevAlmAbn basedataMontPatdevalmabn);

   int insertBasedataMontPatDevAlmAbn(BasedataMontPatDevAlmAbn basedataMontPatdevalmabn);

   int updateBasedataMontPatDevAlmAbn(BasedataMontPatDevAlmAbn basedataMontPatdevalmabn);

   int deleteBasedataMontPatDevAlmAbnByMontPatDevAlmAbnId(Long id);

   int deleteBasedataMontPatDevAlmAbnByMontPatDevAlmAbnIds(Long[] ids);
}
